..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

Changes
=======

Version 1.0.1 (released 2018-05-25)

- Fixes issue with badges being cached.

Version 1.0.0 (released 2018-03-23)

- Initial public release.
